# twvideo-dl

A Simple CLI for downloading Videos from X, formaly Twitter.

## Install

```bash
pip install twvideo-dl
```

## How to use

```shellsession
$ twvideo-dl https://twitter.com/YouTube/status/988453821851619330
```
